@@ -23,10 +23,11 @@ use strict;
 use warnings;
 
 use Glib;
+use Gtk2;
 
 require DynaLoader;
 
-our @ISA = qw(DynaLoader);
+our @ISA = qw( DynaLoader );
 
 # the version scheme is:
 #   CLUTTER_MAJOR
@@ -37,7 +38,7 @@ our @ISA = qw(DynaLoader);
 # of the bindings for each point release of libclutter,
 # which should be enough even in case of brown paper
 # bag releases. -- ebassi
-our $VERSION = '0.230';
+our $VERSION = '0.402';
 
 sub import {
     my $class = shift;
@@ -45,15 +46,13 @@ sub import {
     my $init = 0;
 
     foreach (@_) {
-	    if (/^[-:]?init$/) {
-            $init = 1;
-        }
-        else {
-            $class->VERSION($_);
-        }
+	    if    (/^[-:]?init$/)     { $init = 1;           }
+        elsif (/^[-:]?gst-init$/) { $init = 2;           }
+        else                      { $class->VERSION($_); }
     }
 
-    Clutter->init() if $init;
+    Clutter->init()      if $init == 1;
+    Clutter::Gst->init() if $init == 2;
 }
 
 sub dl_load_flags { $^O eq 'darwin' ? 0x00 : 0x01 }
@@ -63,87 +62,12 @@ XSLoader::load('Clutter', $VERSION);
 
 # Preloaded methods go here
 
-package Clutter::Alpha;
-
-sub ramp
-{
-    my $alpha = shift;
-    my $timeline = $alpha->get_timeline();
-
-    my $current_frame_num = $timeline->get_current_frame();
-    my $n_frames = $timeline->get_n_frames();
-
-    if ($current_frame_num > ($n_frames / 2)) {
-        return ($n_frames - $current_frame_num)
-               * Clutter::Alpha->MAX_ALPHA
-               / ($n_frames / 2);
-    }
-
-    return $current_frame_num
-           * Clutter::Alpha->MAX_ALPHA
-           / ($n_frames / 2);
-}
-
-sub ramp_dec
-{
-    my $alpha = shift;
-    my $timeline = $alpha->get_timeline();
-
-    my $current_frame_num = $timeline->get_current_frame();
-    my $n_frames = $timeline->get_n_frames();
-
-    return ($n_frames - $current_frame_num)
-           * Clutter::Alpha->MAX_ALPHA
-           / $n_frames;
-}
-
-sub ramp_inc
-{
-    my $alpha = shift;
-    my $timeline = $alpha->get_timeline();
-
-    my $current_frame_num = $timeline->get_current_frame();
-    my $n_frames = $timeline->get_n_frames();
-
-    return $current_frame_num
-           * Clutter::Alpha->MAX_ALPHA
-           / $n_frames;
-}
-
-sub sine
-{
-    use Math::Trig ':pi';
-
-    my $alpha = shift;
-    my $timeline = $alpha->get_timeline();
-
-    my $current_frame_num = $timeline->get_current_frame();
-    my $n_frames = $timeline->get_n_frames();
-
-    my $x = ($current_frame_num * pi2) / $n_frames;
-    my $sine_val = (sin ($x - (pip2)) + 1) * .5;
-
-    return ($sine_val * Clutter::Alpha->MAX_ALPHA);
-}
-
-sub square
-{
-    my $alpha = shift;
-    my $timeline = $alpha->get_timeline();
-
-    my $current_frame_num = $timeline->get_current_frame();
-    my $n_frames = $timeline->get_n_frames();
-
-    return Clutter::Alpha->MAX_ALPHA
-        if ($current_frame_num > ($n_frames / 2));
-
-    return 0;
-}
-
 package Clutter::Color;
 
 use overload
     '==' => \&Clutter::Color::equal,
+    '+' => \&Clutter::Color::add,
+    '-' => \&Clutter::Color::subtract,
     fallback => 1;
 
 package Clutter::Knot;
@@ -152,6 +76,12 @@ use overload
     '==' => \&Clutter::Knot::equal,
     fallback => 1;
 
+package Clutter::Vertex;
+
+use overload
+    '==' => \&Clutter::Vertex::equal,
+    fallback => 1;
+
 package Clutter;
 
 1;
@@ -224,6 +154,10 @@ changed for the Perl bindings.
 The C<ClutterCloneTexture> has been moved under the L<Clutter::Texture>
 package name, to reinforce the inheritance.
 
+=item ClutterCairo =E<gt> Clutter::Texture::Cairo
+
+As above, the name has been changed to reinforce the inheritance.
+
 =back
 
 =head1 AUTHOR
@@ -235,18 +169,19 @@ Emmanuele Bassi E<lt>ebassi (AT) openedhand (DOT) comE<gt>
 Copyright (C) 2006  OpenedHand Ltd.
 
 This module is free software; you can redistribute it and/or
-modify it under the terms of the GNU Library General Public
-License as published by the Free Software Foundation; either
-version 2 of the License, or (at your option) any later version.
+modify it under the terms of the GNU Lesser General Public
+License as published by the Free Software Foundation, version 2.1;
+or, at your option, under the terms of The Artistic License.
 
 This module is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-Library General Public License for more details.
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 
 You should have received a copy of the GNU Library General Public
 License along with this module; if not, write to the 
 Free Software Foundation, Inc., 59 Temple Place - Suite 330, 
 Boston, MA  02111-1307  USA.
 
+For the terms of The Artistic License, see L<perlartistic>.
+
 =cut
